Learn R Programming

nzilbb.labbcat (version 1.5-1)

appendLabels: Appends labels of annotations on given layers to a dataframe of matches.

Description

This is a version of getMatchLabels that can have a dataframe of matches piped into it, and returns the dataframe with columns appended.

Usage

appendLabels(
  matches,
  layer.ids,
  target.offset = 0,
  annotations.per.layer = 1,
  page.length = 1000,
  no.progress = FALSE,
  labbcat.url = NULL,
  column.prefix = NULL
)

Arguments

Value

matches with the labels appended as new columns.

See Also

  • getMatchLabels

  • getMatches

Examples

Run this code
if (FALSE) {
## Perform a search
results <- getMatches(labbcat.url, list(orthography="quake")) |>    
   appendLabels("topic") ## Get the topic annotations for the matches
}

Run the code above in your browser using DataLab