The maximum ordinal for the counted annotations. e.g. a max.ordinal
of 1 will ensure that only the first annotation for each parent is returned. If
max.ordinal is null, then all annotations are counted, regardless of their ordinal.
if (FALSE) {
## Count the number of words in UC427_ViktoriaPapp_A_ENG.eaftoken.count <- countAnnotations(labbcat.url, "UC427_ViktoriaPapp_A_ENG.eaf", "orthography")
}