countMatchingAnnotations: Gets the number of annotations matching a particular pattern
Description
Returns the number of annotations in the corpus that match the given expression.
Usage
countMatchingAnnotations(labbcat.url, expression)
Value
The number of annotations that match the expression.
Arguments
labbcat.url
URL to the LaBB-CAT instance
expression
An expression that determines which annotations match. This must
match by either id or layer.id.
The expression language is currently not well defined, but is based on JavaScript
syntax. e.g.:
if (FALSE) {
## count the number of topic tags that include the word 'quake'countMatchingAnnotations(labbcat.url, "layer.id == 'topic' && /.*quake.*/.test(label)")
}