powered by
This function deletes the given media file associated with the given transcript.
deleteMedia(labbcat.url, id, file.name)
URL to the LaBB-CAT instance
The ID transcript whose media will be deleted.
The media file name, e.g. media.file$name
For this function to work, the credentials used to connect to the server must have at least 'edit' access.
getAvailableMedia
saveMedia
if (FALSE) { ## delete the mp3 file of a transcript from the server deleteMedia(labbcat.url, "my-transcript.eaf", "my-transcript.mp3") }
Run the code above in your browser using DataLab