powered by
This function deletes the identified participant from the corpus, but only if they do not appear in any transcripts.
deleteParticipant(labbcat.url, id)
TRUE if the participant's record was delete, FALSE otherwise.
URL to the LaBB-CAT instance
The participant ID - either the unique internal database ID, or their name.
getParticipant
saveParticipant
if (FALSE) { ## Create a new participant record saveParticipant(labbcat.url, "Juan Perez") ### Delete the participant we just created deleteParticipant(labbcat.url, "Juan Perez") }
Run the code above in your browser using DataLab