powered by
Gets a layer definition
getLayer(labbcat.url, id)
The definition of the given layer, with members:
id The layer's unique ID
parentId The layer's parent layer ID
description The description of the layer
alignment The layer's alignment - 0 for none, 1 for point alignment, 2 for interval alignment
peers Whether children have peers or not
peersOverlap Whether child peers can overlap or not
parentIncludes Whether the parent t-includes the child
saturated Whether children must temporally fill the entire parent duration (true) or not (false)
type The type for labels on this layer
validLabels List of valid label values for this layer
URL to the LaBB-CAT instance
ID of the layer to get the definition for
Other Annotation layer functions: deleteLayer(), generateLayer(), getLayerIds(), getLayers(), newLayer(), saveLayer()
deleteLayer()
generateLayer()
getLayerIds()
getLayers()
newLayer()
saveLayer()
if (FALSE) { ## Get the definition of the orthography layer orthography.layer <- getLayer("https://labbcat.canterbury.ac.nz/demo/", "orthography") }
Run the code above in your browser using DataLab