Learn R Programming

nzilbb.labbcat (version 1.5-1)

getMediaUrl: Gets the URL of the given media track for a given transcript

Description

Gets the URL of the given media track for a given transcript

Usage

getMediaUrl(labbcat.url, id, track.suffix = "", mime.type = "audio/wav")

Value

A URL to the given media for the given transcript.

Arguments

labbcat.url

URL to the LaBB-CAT instance.

id

A transcript ID (i.e. transcript name).

track.suffix

The track suffix of the media.

mime.type

The MIME type of the media, e.g. "audio/wav" or "application/f0".

See Also

  • getTranscriptIds

  • getMedia

Examples

Run this code
if (FALSE) {
## Get URL for the WAV file for BR2044_OllyOhlson.eaf
wavUrl <- getMediaUrl(labbcat.url, "BR2044_OllyOhlson.eaf")

## Get URL for the 'QuakeFace' video file for BR2044_OllyOhlson.eaf
quakeFaceMp4Url <- getMediaUrl(labbcat.url, "BR2044_OllyOhlson.eaf", "_face", "video/mp4")
}

Run the code above in your browser using DataLab