If you are using R interactively, this step is optional, as all functions will prompt
the user for the username and password if required. If the script is running in
RStudio, then the RStudio password input dialog is used, hiding the credentials from view.
Otherwise, the console is used, and credentials are visible.
The recommended approach is to not use labbcatCredentials, to avoid saving
user credentials in script files that may eventually become visible to other.
Use labbcatCredentials only in cases where the script execution is unsupervised,
e.g. if you are executing an R script from a shell script, or using Knit to render an
Rmarkdown document.
If you must use labbcatCredentials, avoid including the actual username and password in
your script. The recommended approach is to store the username and password (and
perhaps the URL too) in your .Renviron file (in your home directory, or the
project directory), like this:
LABBCAT_URL=https://labbcat.canterbury.ac.nz/demo/
LABBCAT_USERNAME=demo
LABBCAT_PASSWORD=demo
And then call Sys.getenv to retrieve the
username/password, as illustrated in the example.