Learn R Programming

nzilbb.labbcat (version 1.5-1)

removeLayerDictionaryEntry: Removes an entry from a layer dictionary

Description

This function removes an existing entry from the dictionary that manages a given layer, and updates all affected tokens in the corpus. Words can have multiple entries.

Usage

removeLayerDictionaryEntry(labbcat.url, layer.id, key, entry = NULL)

Arguments

Value

NULL if the entry was added, or a list of error messages if not.

Details

You must have edit privileges in LaBB-CAT in order to be able to use this function.

See Also

Other dictionary functions: addDictionaryEntry(), addLayerDictionaryEntry(), deleteLexicon(), getDictionaries(), getDictionaryEntries(), loadLexicon(), removeDictionaryEntry()

Examples

Run this code
if (FALSE) {
## Remove a pronunciation for "robert" from the phonemes layer dictionary
removeLayerDictionaryEntry(labbcat.url, "phonemes", "robert", "'rQ-bErt")
}

Run the code above in your browser using DataLab