Learn R Programming

nzilbb.labbcat (version 1.5-1)

saveMedia: Uploads the given media for the given transcript

Description

This function upload a media file to LaBB-CAT, associating it with a given transcript.

Usage

saveMedia(labbcat.url, id, media, track.suffix = NULL)

Value

A named list describing the attributes of the uploaded media:

  • trackSuffix The track suffix of the media

  • mimeType The MIME type of the file

  • url URL to the content of the file

  • name Name of the file in LaBB-CAT

Arguments

labbcat.url

URL to the LaBB-CAT instance

id

The transcript ID.

media

The path to the media to upload.

track.suffix

The track suffix for the media, if any.

Details

For this function to work, the credentials used to connect to the server must have at least 'edit' access.

See Also

  • getAvailableMedia

  • deleteMedia

Examples

Run this code
if (FALSE) {

## upload transcript
saveMedia(
    labbcat.url, "my-transcript.eaf", "my-transcript/audio/room-mic.wav", "-room")
}

Run the code above in your browser using DataLab