Learn R Programming

nzilbb.labbcat (version 1.5-1)

transcriptUploadDelete: Cancel a transcript upload started by a previous call to transcriptUpload().

Description

This cancels a transcript upload started by a previous call to transcriptUpload() deleting any uploaded files from the server.

Usage

transcriptUploadDelete(labbcat.url, id)

Arguments

labbcat.url

URL to the LaBB-CAT instance

id

Upload ID returned by the prior call to transcriptUpload().

See Also

  • transcriptUpload

  • transcriptUploadParameters

  • newTranscript

  • updateTranscript

Examples

Run this code
if (FALSE) {
## Get attributes for new transcript
corpus <- getCorpusIds(labbcat.url)[1]
transcript.type.layer <- getLayer(labbcat.url, "transcript_type")
transcript.type <- transcript.type.layer$validLabels[[1]]

## upload transcript and its media
result <- transcriptUpload(labbcat.url, "my-transcript.eaf", "my-transcript.wav", FALSE)

## Changed our mind, cancel this upload
transcriptUploadDelete(labbcat.url, result$id)
}

Run the code above in your browser using DataLab