This function uploads a file (e.g. Praat TextGrid) representing a fragment of a
transcript, with annotations or alignments to update in LaBB-CAT's version of the
transcript.
Usage
updateFragment(labbcat.url, fragment.path)
Value
A named list with information about the fragment that was updated.
Arguments
labbcat.url
URL to the LaBB-CAT instance
fragment.path
The path to the fragment to upload.
Details
For this function to work, the credentials used to connect to the server must have at
least 'edit' access.