Learn R Programming

nzilbb.labbcat (version 1.5-1)

updateTranscript: Update an existing transcript

Description

This function uploads a new version of an existing transcript.

Usage

updateTranscript(labbcat.url, transcript.path, no.progress = FALSE)

Value

The ID of the updated transcript in the corpus

Arguments

labbcat.url

URL to the LaBB-CAT instance

transcript.path

The path to the transcript to upload.

no.progress

TRUE to suppress visual progress bar. Otherwise, progress bar will be shown when interactive().

Details

NB This method of uploading is an alternative to using transcriptUpload and transcriptUploadParameters.

For this function to work, the credentials used to connect to the server must have at least 'edit' access.

See Also

  • transcriptUpload

  • transcriptUploadParameters

  • transcriptUploadDelete

  • newTranscript

Examples

Run this code
if (FALSE) {
## upload new verison of transcript transcript
updateTranscript(labbcat.url, "my-transcript.eaf")
}

Run the code above in your browser using DataLab