Learn R Programming

nzilbb.labbcat (version 1.5-1)

deleteLayer: Deletes an existing layer

Description

This function deletes an existing annotation layer, including all annotation data associated with it.

Usage

deleteLayer(labbcat.url, layer.id)

Arguments

Value

NULL, or an error message if deletion failed.

Details

You must have administration privileges in LaBB-CAT in order to be able to use this function.

See Also

Other Annotation layer functions: generateLayer(), getLayer(), getLayerIds(), getLayers(), newLayer(), saveLayer()

Examples

Run this code
if (FALSE) {
## Delete the phonemes layer
deleteLayer(labbcat.url, "phonemes")
}

Run the code above in your browser using DataLab