powered by
This function deletes an existing annotation layer, including all annotation data associated with it.
deleteLayer(labbcat.url, layer.id)
NULL, or an error message if deletion failed.
You must have administration privileges in LaBB-CAT in order to be able to use this function.
Other Annotation layer functions: generateLayer(), getLayer(), getLayerIds(), getLayers(), newLayer(), saveLayer()
generateLayer()
getLayer()
getLayerIds()
getLayers()
newLayer()
saveLayer()
if (FALSE) { ## Delete the phonemes layer deleteLayer(labbcat.url, "phonemes") }
Run the code above in your browser using DataLab