powered by
This function upload a media file to LaBB-CAT, associating it with a given transcript.
saveMedia(labbcat.url, id, media, track.suffix = NULL)
A named list describing the attributes of the uploaded media:
trackSuffix The track suffix of the media
mimeType The MIME type of the file
url URL to the content of the file
name Name of the file in LaBB-CAT
URL to the LaBB-CAT instance
The transcript ID.
The path to the media to upload.
The track suffix for the media, if any.
For this function to work, the credentials used to connect to the server must have at least 'edit' access.
getAvailableMedia
deleteMedia
if (FALSE) { ## upload transcript saveMedia( labbcat.url, "my-transcript.eaf", "my-transcript/audio/room-mic.wav", "-room") }
Run the code above in your browser using DataLab